.. _spkg_pandoc:

pandoc: A document converter
============================

Description
-----------

This dummy package represents the document converter pandoc.

We do not have an SPKG for it. The purpose of this dummy package is to
associate system package lists with it.


Type
----

optional


Dependencies
------------



Version Information
-------------------



Equivalent System Packages
--------------------------

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add pandoc

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S pandoc

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install pandoc

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install pandoc

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install pandoc

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install textproc/hs-pandoc

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge app-text/pandoc

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install pandoc

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install pandoc

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install pandoc

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install pandoc

# See https://repology.org/project/pandoc/versions

If the system package is installed, ``./configure`` will check if it can be used.
